@@ -1,2 +1,2 @@
-from . import frame, cells
+from . import frame, cells, rows
 from .core import FrameValidator, CellsValidator, RowsValidator
\ No newline at end of file
